==> AsposeCellsCloud-CellsApi-25.12.tar.gz: AsposeCellsCloud-CellsApi-25.12/docs/model/PivotField.md <==
# AsposeCellsCloud::Object::PivotField 

## Load the model package
```perl
use AsposeCellsCloud::Object::PivotField;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**AutoShowCount** | **int** | Represent the number of top or bottom items            that are automatically shown in the specified PivotTable field. |
**AutoShowField** | **int** |  |
**AutoSortField** | **int** |  |
**BaseField** | **int** |  |
**BaseIndex** | **int** |  |
**BaseItem** | **int** |  |
**BaseItemPosition** | **string** |  |
**CurrentPageItem** | **int** |  |
**DataDisplayFormat** | **string** |  |
**DisplayName** | **string** |  |
**DragToColumn** | **boolean** |  |
**DragToData** | **boolean** |  |
**DragToHide** | **boolean** |  |
**DragToPage** | **boolean** |  |
**DragToRow** | **boolean** |  |
**Function** | **string** |  |
**InsertBlankRow** | **boolean** |  |
**IsAscendShow** | **boolean** |  |
**IsAscendSort** | **boolean** |  |
**IsAutoShow** | **boolean** |  |
**IsAutoSort** | **boolean** |  |
**IsAutoSubtotals** | **boolean** |  |
**IsCalculatedField** | **boolean** |  |
**IsIncludeNewItemsInFilter** | **boolean** |  |
**IsInsertPageBreaksBetweenItems** | **boolean** |  |
**IsMultipleItemSelectionAllowed** | **boolean** |  |
**IsRepeatItemLabels** | **boolean** |  |
**ItemCount** | **int** |  |
**Items** | **ARRAY[string]** |  |
**Name** | **string** |  |
**Number** | **int** |  |
**NumberFormat** | **string** |  |
**OriginalItems** | **ARRAY[string]** |  |
**PivotItems** | **ARRAY[PivotItem]** |  |
**Position** | **int** |  |
**ShowAllItems** | **boolean** |  |
**ShowCompact** | **boolean** |  |
**ShowInOutlineForm** | **boolean** |  |
**ShowSubtotalAtTop** | **boolean** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/PivotField.md <==
# AsposeCellsCloud::Object::PivotField 

## Load the model package
```perl
use AsposeCellsCloud::Object::PivotField;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**AutoShowCount** | **int** | Represent the number of top or bottom items            that are automatically shown in the specified PivotTable field. |
**AutoShowField** | **int** |  |
**AutoSortField** | **int** |  |
**BaseField** | **int** |  |
**BaseIndex** | **int** |  |
**BaseItem** | **int** |  |
**BaseItemPosition** | **string** |  |
**CurrentPageItem** | **int** |  |
**DataDisplayFormat** | **string** |  |
**DisplayName** | **string** |  |
**DragToColumn** | **boolean** |  |
**DragToData** | **boolean** |  |
**DragToHide** | **boolean** |  |
**DragToPage** | **boolean** |  |
**DragToRow** | **boolean** |  |
**Function** | **string** |  |
**InsertBlankRow** | **boolean** |  |
**IsAscendShow** | **boolean** |  |
**IsAscendSort** | **boolean** |  |
**IsAutoShow** | **boolean** |  |
**IsAutoSort** | **boolean** |  |
**IsAutoSubtotals** | **boolean** |  |
**IsCalculatedField** | **boolean** |  |
**IsIncludeNewItemsInFilter** | **boolean** |  |
**IsInsertPageBreaksBetweenItems** | **boolean** |  |
**IsMultipleItemSelectionAllowed** | **boolean** |  |
**IsRepeatItemLabels** | **boolean** |  |
**ItemCount** | **int** |  |
**Items** | **ARRAY[string]** |  |
**Name** | **string** |  |
**Number** | **int** |  |
**NumberFormat** | **string** |  |
**OriginalItems** | **ARRAY[string]** |  |
**PivotItems** | **ARRAY[PivotItem]** |  |
**Position** | **int** |  |
**ShowAllItems** | **boolean** |  |
**ShowCompact** | **boolean** |  |
**ShowInOutlineForm** | **boolean** |  |
**ShowSubtotalAtTop** | **boolean** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
